Augmentations (albumentations.augmentations)
============================================

Transforms
----------
.. automodule:: albumentations.augmentations.transforms
    :members:

Functional transforms
---------------------
.. automodule:: albumentations.augmentations.functional
    :members:

Helper functions for working with bounding boxes
------------------------------------------------
.. automodule:: albumentations.augmentations.bbox_utils
    :members:

Helper functions for working with keypoints
------------------------------------------------
.. automodule:: albumentations.augmentations.keypoints_utils
    :members:
